# TikTok Business API SDK - Python

Comprehensive collection of client libraries that enable our developers to build software to integrate with Business API faster and in a more standardized way.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.1.5

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage

Please refer to the "Integration with Python SDK" section in the [README.md](https://github.com/tiktok/tiktok-business-api-sdk/blob/main/README.md) under the root folder.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import business_api_client
from business_api_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = business_api_client.APPManagementApi(business_api_client.ApiClient(configuration))
access_token = 'access_token_example' # str | Authorized access token. For details, see [Authentication](https://ads.tiktok.com/marketing_api/docs?id=1738373164380162).
body = business_api_client.AppCreateBody() # AppCreateBody |  (optional)

try:
    # Create an app. [APP Create](https://business-api.tiktok.com/portal/docs?id=1740859280958466)
    api_response = api_instance.app_create(access_token, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling APPManagementApi->app_create: %s\n" % e)

# create an instance of the API class
api_instance = business_api_client.APPManagementApi(business_api_client.ApiClient(configuration))
advertiser_id = 'advertiser_id_example' # str | 
app_id = 'app_id_example' # str | 
access_token = 'access_token_example' # str | Authorized access token. For details, see [Authentication](https://ads.tiktok.com/marketing_api/docs?id=1738373164380162).

try:
    # Get info of an app. [APP Info](https://business-api.tiktok.com/portal/docs?id=1740859272887297)
    api_response = api_instance.app_info(advertiser_id, app_id, access_token)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling APPManagementApi->app_info: %s\n" % e)

# create an instance of the API class
api_instance = business_api_client.APPManagementApi(business_api_client.ApiClient(configuration))
advertiser_id = 'advertiser_id_example' # str | Advertiser ID.
access_token = 'access_token_example' # str | Authorized access token. For details, see [Authentication](https://ads.tiktok.com/marketing_api/docs?id=1738373164380162).
app_platform_ids = ['app_platform_ids_example'] # list[str] | List of app platform ID for filter purpose. (optional)

try:
    # Get the app list. [APP List](https://business-api.tiktok.com/portal/docs?id=1740859313270786)
    api_response = api_instance.app_list(advertiser_id, access_token, app_platform_ids=app_platform_ids)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling APPManagementApi->app_list: %s\n" % e)

# create an instance of the API class
api_instance = business_api_client.APPManagementApi(business_api_client.ApiClient(configuration))
app_id = 'app_id_example' # str | Your App ID, obtained after successfully creating your app.
advertiser_id = 'advertiser_id_example' # str | Advertiser ID
optimization_goal = 'optimization_goal_example' # str | Optimization goal. For enum values, see Enumeration-Optimization Goal for more
access_token = 'access_token_example' # str | Authorized access token. For details, see [Authentication](https://ads.tiktok.com/marketing_api/docs?id=1738373164380162).
placement = ['placement_example'] # list[str] | The apps where you want to deliver your ads. Required when placement_type is PLACEMENT_TYPE_NORMAL, and ignored when placement_type is PLACEMENT_TYPE_AUTOMATIC. Note: Currently, we support PLACEMENT_TIKTOK, PLACEMENT_PANGLE and PLACEMENT_GLOBAL_APP_BUNDLE. Please don't select PLACEMENT_TOPBUZZ or PLACEMENT_HELO as your placements since they've been deprecated. For a full list of enum values, see Enumeration - Placement. For Product Sales campaigns (objective_type = PRODUCT_SALES), only TikTok placement (PLACEMENT_TIKTOK) is supported. (optional)
placement_type = 'placement_type_example' # str | 版位类型。 枚举值：PLACEMENT_TYPE_AUTOMATIC（自动版位）,PLACEMENT_TYPE_NORMAL （编辑版位）。 默认值: PLACEMENT_TYPE_NORMAL。 (optional)
objective = 'objective_example' # str | Advertising Objective. For enum values, see Enumeration-Advertising Objective (optional)
available_only = true # bool | Whether to return only available conversion events. The default value: True (only return available conversion events) (optional)
is_skan = true # bool | Whether the app is using Skan features. (optional)
app_promotion_type = 'app_promotion_type_example' # str | App promotion type. Required when objective_type is APP_PROMOTION. Enum values: APP_INSTALL, APP_RETARGETING. Note: APP_INSTALL can be used in an iOS14 Dedicated Campaign, while APP_RETARGETING cannot be used. (optional)

try:
    # Get App Conversion Events. [App Optimization Event](https://business-api.tiktok.com/portal/docs?id=1740859338750977)
    api_response = api_instance.app_optimization_event(app_id, advertiser_id, optimization_goal, access_token, placement=placement, placement_type=placement_type, objective=objective, available_only=available_only, is_skan=is_skan, app_promotion_type=app_promotion_type)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling APPManagementApi->app_optimization_event: %s\n" % e)

# create an instance of the API class
api_instance = business_api_client.APPManagementApi(business_api_client.ApiClient(configuration))
app_id = 'app_id_example' # str | 
advertiser_id = 'advertiser_id_example' # str | 
access_token = 'access_token_example' # str | Authorized access token. For details, see [Authentication](https://ads.tiktok.com/marketing_api/docs?id=1738373164380162).

try:
    # Get App Retargeting Events. [App Optimization Event Retargeting](https://business-api.tiktok.com/portal/docs?id=1740859371033601)
    api_response = api_instance.app_optimization_event_retargeting(app_id, advertiser_id, access_token)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling APPManagementApi->app_optimization_event_retargeting: %s\n" % e)

# create an instance of the API class
api_instance = business_api_client.APPManagementApi(business_api_client.ApiClient(configuration))
access_token = 'access_token_example' # str | Authorized access token. For details, see [Authentication](https://ads.tiktok.com/marketing_api/docs?id=1738373164380162).
body = business_api_client.AppUpdateBody() # AppUpdateBody |  (optional)

try:
    # Update an app. [APP Update](https://business-api.tiktok.com/portal/docs?id=1740859300069378)
    api_response = api_instance.app_update(access_token, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling APPManagementApi->app_update: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://business-api.tiktok.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*APPManagementApi* | [**app_create**](docs/APPManagementApi.md#app_create) | **POST** /app/create/ | Create an app. [APP Create](https://business-api.tiktok.com/portal/docs?id&#x3D;1740859280958466)
*APPManagementApi* | [**app_info**](docs/APPManagementApi.md#app_info) | **GET** /app/info/ | Get info of an app. [APP Info](https://business-api.tiktok.com/portal/docs?id&#x3D;1740859272887297)
*APPManagementApi* | [**app_list**](docs/APPManagementApi.md#app_list) | **GET** /app/list/ | Get the app list. [APP List](https://business-api.tiktok.com/portal/docs?id&#x3D;1740859313270786)
*APPManagementApi* | [**app_optimization_event**](docs/APPManagementApi.md#app_optimization_event) | **GET** /app/optimization_event/ | Get App Conversion Events. [App Optimization Event](https://business-api.tiktok.com/portal/docs?id&#x3D;1740859338750977)
*APPManagementApi* | [**app_optimization_event_retargeting**](docs/APPManagementApi.md#app_optimization_event_retargeting) | **GET** /app/optimization_event/retargeting/ | Get App Retargeting Events. [App Optimization Event Retargeting](https://business-api.tiktok.com/portal/docs?id&#x3D;1740859371033601)
*APPManagementApi* | [**app_update**](docs/APPManagementApi.md#app_update) | **POST** /app/update/ | Update an app. [APP Update](https://business-api.tiktok.com/portal/docs?id&#x3D;1740859300069378)
*AccountManagementApi* | [**advertiser_info**](docs/AccountManagementApi.md#advertiser_info) | **GET** /advertiser/info/ | Get ad account details. [Advertiser Info](https://business-api.tiktok.com/portal/docs?id&#x3D;1739593083610113)
*AccountManagementApi* | [**advertiser_update**](docs/AccountManagementApi.md#advertiser_update) | **POST** /advertiser/update/ | Update an ad account. [Advertiser Update](https://business-api.tiktok.com/portal/docs?id&#x3D;1739939050770434)
*AccountManagementApi* | [**pangle_audience_package_get**](docs/AccountManagementApi.md#pangle_audience_package_get) | **GET** /pangle_audience_package/get/ | Get the Pangle audience packages. [Pangle Audience Package Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1740040177229826)
*AccountManagementApi* | [**pangle_block_list_get**](docs/AccountManagementApi.md#pangle_block_list_get) | **GET** /pangle_block_list/get/ | Get the Pangle block list. [Pangle Block List Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1740039957181441)
*AccountManagementApi* | [**pangle_block_list_update**](docs/AccountManagementApi.md#pangle_block_list_update) | **POST** /pangle_block_list/update/ | Update the Pangle block list. [Pangle Block List Update](https://business-api.tiktok.com/portal/docs?id&#x3D;1740040139110466)
*AccountManagementApi* | [**term_check**](docs/AccountManagementApi.md#term_check) | **GET** /term/check/ | Check the status of Terms. [Term Check](https://business-api.tiktok.com/portal/docs?id&#x3D;1737192304571394)
*AccountManagementApi* | [**term_confirm**](docs/AccountManagementApi.md#term_confirm) | **POST** /term/confirm/ | Sign Terms. [Term Confirm](https://business-api.tiktok.com/portal/docs?id&#x3D;1737192284435457)
*AccountManagementApi* | [**term_get**](docs/AccountManagementApi.md#term_get) | **GET** /term/get/ | Get Terms. [Term Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1737191909315585)
*AdApi* | [**ad_create**](docs/AdApi.md#ad_create) | **POST** /ad/create/ | Upload your ad creatives (pictures, videos, texts, call-to-action) and create an ad. For different placements, the creative formats and requirements are different. Upload your ad creatives according to the placement requirements. Each ad group can have up to 20 ads. See here to learn about how to create ads. [Ad create](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739953377508354)
*AdApi* | [**ad_get**](docs/AdApi.md#ad_get) | **GET** /ad/get/ | Get the data of regular ads and ACO ads. [Ad get](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1735735588640770)
*AdApi* | [**ad_status_update**](docs/AdApi.md#ad_status_update) | **POST** /ad/status/update/ | To enable, disable or delete an ad or ads [Ad status update](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739953422970882)
*AdApi* | [**ad_update**](docs/AdApi.md#ad_update) | **POST** /ad/update/ | Modify your custom ad creatives such as call-to-action, ad name, text image and video material. To update ACO ads, use the /ad/aco/update/ endpoint. [Ad update](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739953422970882)
*AdAcoApi* | [**ad_aco_create**](docs/AdAcoApi.md#ad_aco_create) | **POST** /ad/aco/create/ | Create an ACO ad by uploading necessary ad creatives to the library. [Ad Aco Create](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739473063234626)
*AdAcoApi* | [**ad_aco_get**](docs/AdAcoApi.md#ad_aco_get) | **GET** /ad/aco/get/ | Get creative materials for an ACO ad, including call-to-actions, texts, ad names, images, or video materials. [Ad Aco Get](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739473020978177)
*AdAcoApi* | [**ad_aco_material_status_update**](docs/AdAcoApi.md#ad_aco_material_status_update) | **POST** /ad/aco/material_status/update/ | Update the status of creative materials for an ACO ad, including ad texts, images, and video materials [Update materials](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739506701165570)
*AdAcoApi* | [**ad_aco_update**](docs/AdAcoApi.md#ad_aco_update) | **POST** /ad/aco/update/ | Modify ACO ad creatives. [Update ACO](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739473077112833)
*AdgroupApi* | [**adgroup_create**](docs/AdgroupApi.md#adgroup_create) | **POST** /adgroup/create/ | Create an ad group. At the ad group level, you can configure placement, audience settings (see Ad Targeting), budget, schedules, as well as bidding and optimization options for ads. To learn about the procedure and the essential data fields to create an ad group, see Create an Ad Group. [Ad Update](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739499616346114)
*AdgroupApi* | [**adgroup_get**](docs/AdgroupApi.md#adgroup_get) | **GET** /adgroup/get/ | Obtain detailed information of an ad group or ad groups. [Adgroup get](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739314558673922)
*AdgroupApi* | [**adgroup_quota**](docs/AdgroupApi.md#adgroup_quota) | **GET** /adgroup/quota/ | Get the dynamic quota [Adgroup Quota](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1768463039162369)
*AdgroupApi* | [**adgroup_status_update**](docs/AdgroupApi.md#adgroup_status_update) | **POST** /adgroup/status/update/ | Enable, disable or delete an ad group. [Adgroup status update](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739591716326402)
*AdgroupApi* | [**adgroup_update**](docs/AdgroupApi.md#adgroup_update) | **POST** /adgroup/update/ | Obtain detailed information of an ad group or ad groups. [Adgroup update](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739586761631745)
*AudienceApi* | [**dmp_custom_audience_apply**](docs/AudienceApi.md#dmp_custom_audience_apply) | **POST** /dmp/custom_audience/apply/ | Apply a shared custom audience [Dmp Custom_audience Apply](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1740245827044354)
*AudienceApi* | [**dmp_custom_audience_apply_log**](docs/AudienceApi.md#dmp_custom_audience_apply_log) | **GET** /dmp/custom_audience/apply/log/ | Get the latest application log of custom audiences [Dmp Custom_audience Apply Log](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1758615737388033)
*AudienceApi* | [**dmp_custom_audience_create**](docs/AudienceApi.md#dmp_custom_audience_create) | **POST** /dmp/custom_audience/create/ | Create an audience by file [Dmp Custom_audience Create](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739940570793985)
*AudienceApi* | [**dmp_custom_audience_delete**](docs/AudienceApi.md#dmp_custom_audience_delete) | **POST** /dmp/custom_audience/delete/ | Delete audiences [Dmp Custom_audience Delete](https://business-api.tiktok.com/portal/docs?id&#x3D;1739940539757569)
*AudienceApi* | [**dmp_custom_audience_file_upload**](docs/AudienceApi.md#dmp_custom_audience_file_upload) | **POST** /dmp/custom_audience/file/upload/ | Upload a data file [Dmp Custom_audience File Upload](https://business-api.tiktok.com/portal/docs?id&#x3D;1739940567842818)
*AudienceApi* | [**dmp_custom_audience_get**](docs/AudienceApi.md#dmp_custom_audience_get) | **GET** /dmp/custom_audience/get/ | Obtain the details of specified audiences [Dmp Custom_audience Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1739940507792385)
*AudienceApi* | [**dmp_custom_audience_list**](docs/AudienceApi.md#dmp_custom_audience_list) | **GET** /dmp/custom_audience/list/ | Get all audiences [Dmp Custom_audience List](https://business-api.tiktok.com/portal/docs?id&#x3D;1739940506015746)
*AudienceApi* | [**dmp_custom_audience_lookalike_create**](docs/AudienceApi.md#dmp_custom_audience_lookalike_create) | **POST** /dmp/custom_audience/lookalike/create/ | Create a lookalike audience [Dmp Custom_audience Lookalike Create](https://business-api.tiktok.com/portal/docs?id&#x3D;1739940511844353)
*AudienceApi* | [**dmp_custom_audience_lookalike_update**](docs/AudienceApi.md#dmp_custom_audience_lookalike_update) | **POST** /dmp/custom_audience/lookalike/update/ | Manually refresh a Lookalike Audience [Dmp Custom_audience Lookalike Update](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1758616888158209)
*AudienceApi* | [**dmp_custom_audience_rule_create**](docs/AudienceApi.md#dmp_custom_audience_rule_create) | **POST** /dmp/custom_audience/rule/create/ | Create an audience by rules [Dmp Custom_audience Rule Create](https://business-api.tiktok.com/portal/docs?id&#x3D;1739940509849601)
*AudienceApi* | [**dmp_custom_audience_share**](docs/AudienceApi.md#dmp_custom_audience_share) | **POST** /dmp/custom_audience/share/ | Share custom audiences with other advertisers [Dmp Custom_audience Share](https://business-api.tiktok.com/portal/docs?id&#x3D;1740245803888706)
*AudienceApi* | [**dmp_custom_audience_share_cancel**](docs/AudienceApi.md#dmp_custom_audience_share_cancel) | **POST** /dmp/custom_audience/share/cancel/ | Stop sharing custom audiences with other advertisers [Dmp Custom_audience Share Cancel](https://business-api.tiktok.com/portal/docs?id&#x3D;1740245829978113)
*AudienceApi* | [**dmp_custom_audience_share_log**](docs/AudienceApi.md#dmp_custom_audience_share_log) | **GET** /dmp/custom_audience/share/log/ | Get the sharing log of a custom audience [Dmp Custom_audience Share Log](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1740245827044354)
*AudienceApi* | [**dmp_custom_audience_update**](docs/AudienceApi.md#dmp_custom_audience_update) | **POST** /dmp/custom_audience/update/ | Update the details of an audience [Dmp Custom_audience Update](https://business-api.tiktok.com/portal/docs?id&#x3D;1739940572667906)
*AudienceApi* | [**dmp_saved_audience_create**](docs/AudienceApi.md#dmp_saved_audience_create) | **POST** /dmp/saved_audience/create/ | Create a Saved Audience [Dmp Saved_audience Create](https://business-api.tiktok.com/portal/docs?id&#x3D;1780154541898754)
*AudienceApi* | [**dmp_saved_audience_delete**](docs/AudienceApi.md#dmp_saved_audience_delete) | **POST** /dmp/saved_audience/delete/ | Delete Saved Audiences [Dmp Saved_audience Delete](https://business-api.tiktok.com/portal/docs?id&#x3D;1780154666312706)
*AudienceApi* | [**dmp_saved_audience_list**](docs/AudienceApi.md#dmp_saved_audience_list) | **GET** /dmp/saved_audience/list/ | Get the details of Saved Audiences [Dmp Saved_audience List](https://business-api.tiktok.com/portal/docs?id&#x3D;1780154619404290)
*AuthenticationApi* | [**oauth2_access_token**](docs/AuthenticationApi.md#oauth2_access_token) | **POST** /oauth2/access_token/ | Get access_token and refresh_token by auth_code. The creator access token is valid for 24 hours and the refresh token is valid for one year. Within one year you will need to refresh the access token with the refresh token on a daily basis. After one year you will need to ask the creator to reauthorize. [Oauth2 Access Token](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739965703387137)
*AuthenticationApi* | [**oauth2_advertiser_get**](docs/AuthenticationApi.md#oauth2_advertiser_get) | **GET** /oauth2/advertiser/get/ | Get a list of advertisers that have granted you permission to manage their accounts. [Authentication Oauth2 Advertiser Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1738455508553729)
*BCApi* | [**advertiser_balance_get**](docs/BCApi.md#advertiser_balance_get) | **GET** /advertiser/balance/get/ | Get ad account balance and budget. [BC Advertiser Balance Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1739939106470913)
*BCApi* | [**advertiser_transaction_get**](docs/BCApi.md#advertiser_transaction_get) | **GET** /advertiser/transaction/get/ | Get transaction records of an ad account. [BC Advertiser Transaction Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1739939116353538)
*BCApi* | [**bc_account_transaction_get**](docs/BCApi.md#bc_account_transaction_get) | **GET** /bc/account/transaction/get/ | Get the transaction records of a BC or ad accounts. [BC Account Transaction Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1792849810925569)
*BCApi* | [**bc_advertiser_create**](docs/BCApi.md#bc_advertiser_create) | **POST** /bc/advertiser/create/ | Create an ad account [BC advertiser create](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739939020318721)
*BCApi* | [**bc_asset_admin_delete**](docs/BCApi.md#bc_asset_admin_delete) | **POST** /bc/asset/admin/delete/ | Delete assets. [BC Asset Admin Delete](https://business-api.tiktok.com/portal/docs?id&#x3D;1739657251102722)
*BCApi* | [**bc_asset_admin_get**](docs/BCApi.md#bc_asset_admin_get) | **GET** /bc/asset/admin/get/ | Get assets of a Business Center as admins. [BC Asset Admin Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1739433007779841)
*BCApi* | [**bc_asset_assign**](docs/BCApi.md#bc_asset_assign) | **POST** /bc/asset/assign/ | Assign assets to a user. [BC Asset Assign](https://business-api.tiktok.com/portal/docs?id&#x3D;1739438211077121)
*BCApi* | [**bc_asset_get**](docs/BCApi.md#bc_asset_get) | **GET** /bc/asset/get/ | Get assets of a Business Center. [BC Asset Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1739432717798401)
*BCApi* | [**bc_asset_group_create**](docs/BCApi.md#bc_asset_group_create) | **POST** /bc/asset_group/create/ | Create an Asset Group in your Business Center. [BC Asset Group Create](https://business-api.tiktok.com/portal/docs?id&#x3D;1749001658583105)
*BCApi* | [**bc_asset_group_delete**](docs/BCApi.md#bc_asset_group_delete) | **POST** /bc/asset_group/delete/ | Remove members&#x27; access to an Asset Group. [BC Asset Group Delete](https://business-api.tiktok.com/portal/docs?id&#x3D;1749001673406466)
*BCApi* | [**bc_asset_group_get**](docs/BCApi.md#bc_asset_group_get) | **GET** /bc/asset_group/get/ | Get the assets or members of an Asset Group in a Business Center. [BC Asset Group Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1749001669670913)
*BCApi* | [**bc_asset_group_list**](docs/BCApi.md#bc_asset_group_list) | **GET** /bc/asset_group/list/ | Get all Asset Groups in your Business Center. [BC Asset Group List](https://business-api.tiktok.com/portal/docs?id&#x3D;1749001665910786)
*BCApi* | [**bc_asset_group_update**](docs/BCApi.md#bc_asset_group_update) | **POST** /bc/asset_group/update/ | Update assets, members or the name of an Asset Group. [BC Asset Group Update](https://business-api.tiktok.com/portal/docs?id&#x3D;1749001662156801)
*BCApi* | [**bc_asset_member_get**](docs/BCApi.md#bc_asset_member_get) | **GET** /bc/asset/member/get/ | Get members by assets. [BC Asset Member Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1739659558931458)
*BCApi* | [**bc_asset_partner_get**](docs/BCApi.md#bc_asset_partner_get) | **GET** /bc/asset/partner/get/ | Get partners by assets. [BC Asset Partner Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1739663268166722)
*BCApi* | [**bc_asset_unassign**](docs/BCApi.md#bc_asset_unassign) | **POST** /bc/asset/unassign/ | Revoke the access to an asset from a user. [BC Asset Unassign](https://business-api.tiktok.com/portal/docs?id&#x3D;1739448126749698)
*BCApi* | [**bc_balance_get**](docs/BCApi.md#bc_balance_get) | **GET** /bc/balance/get/ | Get the balance of a Business Center. [BC Balance Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1739939128198145)
*BCApi* | [**bc_billing_group_create**](docs/BCApi.md#bc_billing_group_create) | **POST** /bc/billing_group/create/ | Create a billing group in a Business Center. [BC Billing Group Create](https://business-api.tiktok.com/portal/docs?id&#x3D;1738947780033537)
*BCApi* | [**bc_billing_group_get**](docs/BCApi.md#bc_billing_group_get) | **GET** /bc/billing_group/get/ | Get all billing groups in a Business Center. [BC Billing Group Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1738944324279297)
*BCApi* | [**bc_billing_group_update**](docs/BCApi.md#bc_billing_group_update) | **POST** /bc/billing_group/update/ | Update settings of a billing group. [BC Billing Group Update](https://business-api.tiktok.com/portal/docs?id&#x3D;1738947843447809)
*BCApi* | [**bc_get**](docs/BCApi.md#bc_get) | **GET** /bc/get/ | Get Business Centers that you have access to. [BC Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1737115687501826)
*BCApi* | [**bc_image_upload**](docs/BCApi.md#bc_image_upload) | **POST** /bc/image/upload/ | Upload certificate images for an ad account. [BC Image Upload](https://business-api.tiktok.com/portal/docs?id&#x3D;1739938996913218)
*BCApi* | [**bc_member_delete**](docs/BCApi.md#bc_member_delete) | **POST** /bc/member/delete/ | Delete member. [BC Member Delete](https://business-api.tiktok.com/portal/docs?id&#x3D;1739939482851329)
*BCApi* | [**bc_member_get**](docs/BCApi.md#bc_member_get) | **GET** /bc/member/get/ | Get BC members. [BC Member Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1739939404802049)
*BCApi* | [**bc_member_invite**](docs/BCApi.md#bc_member_invite) | **POST** /bc/member/invite/ | Invite members to BC. [BC Member Invite](https://business-api.tiktok.com/portal/docs?id&#x3D;1739939455765505)
*BCApi* | [**bc_member_update**](docs/BCApi.md#bc_member_update) | **POST** /bc/member/update/ | Update member information. [BC Member Update](https://business-api.tiktok.com/portal/docs?id&#x3D;1739696704424961)
*BCApi* | [**bc_partner_add**](docs/BCApi.md#bc_partner_add) | **POST** /bc/partner/add/ | Add partner to Business Center. [BC Partner Add](https://business-api.tiktok.com/portal/docs?id&#x3D;1739662756510721)
*BCApi* | [**bc_partner_asset_delete**](docs/BCApi.md#bc_partner_asset_delete) | **POST** /bc/partner/asset/delete/ | Cancel asset sharing. [BC Partner Asset Delete](https://business-api.tiktok.com/portal/docs?id&#x3D;1739662800930817)
*BCApi* | [**bc_partner_asset_get**](docs/BCApi.md#bc_partner_asset_get) | **GET** /bc/partner/asset/get/ | Get partner assets. [BC Partner Asset Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1739662828320769)
*BCApi* | [**bc_partner_delete**](docs/BCApi.md#bc_partner_delete) | **POST** /bc/partner/delete/ | Delete partner. [BC Partner Delete](https://business-api.tiktok.com/portal/docs?id&#x3D;1739662779301890)
*BCApi* | [**bc_partner_get**](docs/BCApi.md#bc_partner_get) | **GET** /bc/partner/get/ | Get partners. [BC Partner Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1739662727395330)
*BCApi* | [**bc_pixel_link_get**](docs/BCApi.md#bc_pixel_link_get) | **GET** /bc/pixel/link/get/ | Use this endpoint to get a list of ad accounts that have been linked to the request pixel. [BC Pixel Link Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1753994966965249)
*BCApi* | [**bc_pixel_link_update**](docs/BCApi.md#bc_pixel_link_update) | **POST** /bc/pixel/link/update/ | Use this endpoint to link and unlink pixel to advertiser accounts. [BC Pixel Link Update](https://business-api.tiktok.com/portal/docs?id&#x3D;1753994950327297)
*BCApi* | [**bc_pixel_transfer**](docs/BCApi.md#bc_pixel_transfer) | **POST** /bc/pixel/transfer/ | Transfer Pixel from Advertiser to BC. [BC Pixel Transfer](https://business-api.tiktok.com/portal/docs?id&#x3D;1753994928261122)
*BCApi* | [**bc_transaction_get**](docs/BCApi.md#bc_transaction_get) | **GET** /bc/transaction/get/ | Get translaction records of a Business Center. [BC Transaction Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1739939140408322)
*BCApi* | [**bc_transfer**](docs/BCApi.md#bc_transfer) | **POST** /bc/transfer/ | Process payments (recharge money to or deduct money from an ad account in a Business Center. [BC Transfer](https://business-api.tiktok.com/portal/docs?id&#x3D;1739939095321601)
*CampaignCreationApi* | [**campaign_create**](docs/CampaignCreationApi.md#campaign_create) | **POST** /campaign/create/ | To create a campaign. To advertise on TikTok Ads, you need to create a campaign and set the Advertising objectives and budget. A regular campaign can contain one or more ad groups. [Campaign Create](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739318962329602)
*CampaignCreationApi* | [**campaign_get**](docs/CampaignCreationApi.md#campaign_get) | **GET** /campaign/get/ | Get all campaigns for an ad account. Optionally, you can use filters in your request to return only certain campaigns. [Campaign get](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739315828649986)
*CampaignCreationApi* | [**campaign_status_update**](docs/CampaignCreationApi.md#campaign_status_update) | **POST** /campaign/status/update/ | Enable, disable or delete a campaign. [Campaign status update](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739320994354178)
*CampaignCreationApi* | [**campaign_update**](docs/CampaignCreationApi.md#campaign_update) | **POST** /campaign/update/ | To modify a campaign after it has been created. Information like campaign name, budget, and budget type can be updated. [Campaign Update](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739320422086657)
*CreativeAssetApi* | [**creative_portfolio_create**](docs/CreativeAssetApi.md#creative_portfolio_create) | **POST** /creative/portfolio/create/ | Create a portfolio [Portfolio create](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739091950439426)
*EventCallbackApi* | [**pixel_batch**](docs/EventCallbackApi.md#pixel_batch) | **POST** /pixel/batch/ | Pixel Track server-to-server batch api
*EventCallbackApi* | [**pixel_track**](docs/EventCallbackApi.md#pixel_track) | **POST** /pixel/track/ | Pixel Track server-to-server api
*FileApi* | [**ad_image_upload**](docs/FileApi.md#ad_image_upload) | **POST** /file/image/ad/upload/ | The function is used to  to upload pictures to the Asset Library and use the obtained image ID for creating ads. [File image Upload](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1739067433456642)
*FileApi* | [**ad_video_info**](docs/FileApi.md#ad_video_info) | **GET** /file/video/ad/info/ | The function is used to get the information about a list of videos [File Video Ad Info](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1740050161973250) from the Asset Library.
*FileApi* | [**ad_video_search**](docs/FileApi.md#ad_video_search) | **GET** /file/video/ad/search/ | The function is used to to search for video creatives in the Asset Library of an ad account. [File Video Search](to search for video creatives in the Asset Library of an ad account.) Library.
*FileApi* | [**ad_video_upload**](docs/FileApi.md#ad_video_upload) | **POST** /file/video/ad/upload/ | The function is used to upload a video to the Asset Library and use the obtained video ID for creating ads. [File Video Upload](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1737587322856449)
*FileApi* | [**file_image_ad_info**](docs/FileApi.md#file_image_ad_info) | **GET** /file/image/ad/info/ | Get image information. [File Image Info](https://business-api.tiktok.com/portal/docs?id&#x3D;1740051721711618)
*IdentityApi* | [**identity_create**](docs/IdentityApi.md#identity_create) | **POST** /identity/create/ | Create a customized user identity. [Identity Create](https://ads.tiktok.com/marketing_api/docs?rid&#x3D;uraumvplog&amp;id&#x3D;1740654203526146)
*IdentityApi* | [**identity_get**](docs/IdentityApi.md#identity_get) | **GET** /identity/get/ | Get a list of identities under an ad account. You can filter results by identity type. [Identity Get](https://ads.tiktok.com/marketing_api/docs?rid&#x3D;uraumvplog&amp;id&#x3D;1740218420781057)
*IdentityApi* | [**identity_video_info**](docs/IdentityApi.md#identity_video_info) | **GET** /identity/video/info/ | Get the information about a TikTok post that you own, if your identity is AUTH_CODE, TT_USER or BC_AUTH_TT. [Identity Video Info](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1738958351620097)
*RecommendToolApi* | [**tool_targeting_category_recommend**](docs/RecommendToolApi.md#tool_targeting_category_recommend) | **POST** /tool/targeting_category/recommend/ | Get recommended interest and action categories [Tool targeting category](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1736275204260866)
*ReportingApi* | [**report_integrated_get**](docs/ReportingApi.md#report_integrated_get) | **GET** /report/integrated/get/ | Run a synchronous report. [Report Integrated Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1740302848100353)
*ReportingApi* | [**report_task_cancel**](docs/ReportingApi.md#report_task_cancel) | **POST** /report/task/cancel/ | Cancel an asynchronous report task. [Report Task Cancel](https://business-api.tiktok.com/portal/docs?id&#x3D;1803615367145537)
*ReportingApi* | [**report_task_check**](docs/ReportingApi.md#report_task_check) | **GET** /report/task/check/ | Get the status of an async report task. [Report Task Check](https://business-api.tiktok.com/portal/docs?id&#x3D;1740302781443073)
*ReportingApi* | [**report_task_create**](docs/ReportingApi.md#report_task_create) | **POST** /report/task/create/ | 
*ToolApi* | [**search_region**](docs/ToolApi.md#search_region) | **GET** /search/region/ | Get available locations by advertiser ID [Search Region](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1773644763581441)
*ToolApi* | [**tool_action_category**](docs/ToolApi.md#tool_action_category) | **GET** /tool/action_category/ | Get action categories [Tool action](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1737166752522241)
*ToolApi* | [**tool_bid_recommend**](docs/ToolApi.md#tool_bid_recommend) | **POST** /tool/bid/recommend/ | Get a suggested bid [Tool Bid Recommend](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1737107845597186)
*ToolApi* | [**tool_brand_safety_partner_authorize_status**](docs/ToolApi.md#tool_brand_safety_partner_authorize_status) | **GET** /tool/brand_safety/partner/authorize/status/ | Get the authorization status of a Brand Safety partner [Tool Brand_safety Partner Authorize Status](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1738456743621634)
*ToolApi* | [**tool_carrier**](docs/ToolApi.md#tool_carrier) | **GET** /tool/carrier/ | Get carriers [Tool carrier](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1737168013095938)
*ToolApi* | [**tool_contextual_tag_get**](docs/ToolApi.md#tool_contextual_tag_get) | **GET** /tool/contextual_tag/get/ | Get available contextual tags [Tool Contextual_tag Get](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1747747118654465)
*ToolApi* | [**tool_contextual_tag_info**](docs/ToolApi.md#tool_contextual_tag_info) | **GET** /tool/contextual_tag/info/ | Get details of contextual tags [Tool Contextual_tag Info](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1747747180830722)
*ToolApi* | [**tool_device_model**](docs/ToolApi.md#tool_device_model) | **GET** /tool/device_model/ | Get device models [Tool device model](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1737172880570369)
*ToolApi* | [**tool_hashtag_get**](docs/ToolApi.md#tool_hashtag_get) | **GET** /tool/hashtag/get/ | Get targeting hashtags by ID [Tool Hashtag Get](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1736280889167874)
*ToolApi* | [**tool_hashtag_recommend**](docs/ToolApi.md#tool_hashtag_recommend) | **GET** /tool/hashtag/recommend/ | Search for targeting hashtags [Tool Hashtag Recommend](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1736271339521025)
*ToolApi* | [**tool_interest_category**](docs/ToolApi.md#tool_interest_category) | **GET** /tool/interest_category/ | Get interest categories [Tool Interest category](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1737174348712961)
*ToolApi* | [**tool_interest_keyword_get**](docs/ToolApi.md#tool_interest_keyword_get) | **GET** /tool/interest_keyword/get/ | Get additional interest categories by ID [Tool Interest_keyword Get](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1763590894544897)
*ToolApi* | [**tool_interest_keyword_recommend**](docs/ToolApi.md#tool_interest_keyword_recommend) | **GET** /tool/interest_keyword/recommend/ | Get interest keywords [Tool kyword recommend](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1737180852720642)
*ToolApi* | [**tool_language**](docs/ToolApi.md#tool_language) | **GET** /tool/language/ | Get languages [Tool Language](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1737188554152962)
*ToolApi* | [**tool_open_url**](docs/ToolApi.md#tool_open_url) | **GET** /tool/open_url/ | Get a TikTok in-app link [Tool Open_url](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1738457335681026)
*ToolApi* | [**tool_os_version**](docs/ToolApi.md#tool_os_version) | **GET** /tool/os_version/ | Get OS versions [Tool Os_version](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1738308662898689)
*ToolApi* | [**tool_phone_region_code**](docs/ToolApi.md#tool_phone_region_code) | **GET** /tool/phone_region_code/ | Get region calling codes and region codes for phone numbers [Tool Phone_region_code](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1774488637039618)
*ToolApi* | [**tool_region**](docs/ToolApi.md#tool_region) | **GET** /tool/region/ | Get available locations [Tool Region](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1737189539571713)
*ToolApi* | [**tool_targeting_info**](docs/ToolApi.md#tool_targeting_info) | **POST** /tool/targeting/info/ | Obtain details about location targeting tags by ID [Tool Targeting Info](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1761237001980929)
*ToolApi* | [**tool_targeting_list**](docs/ToolApi.md#tool_targeting_list) | **GET** /tool/targeting/list/ | Get internet service providers [Tool Targeting List](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1762962378261506)
*ToolApi* | [**tool_targeting_search**](docs/ToolApi.md#tool_targeting_search) | **POST** /tool/targeting/search/ | Search for location targeting tags [Tool Targeting Search](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1761236883355649)
*ToolApi* | [**tool_timezone**](docs/ToolApi.md#tool_timezone) | **GET** /tool/timezone/ | Get time zones [Tool Timezone](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1738455961470977)
*ToolApi* | [**tool_url_validate**](docs/ToolApi.md#tool_url_validate) | **GET** /tool/url_validate/ | Get the verification results of a URL [Tool Url_validate](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1774487686007810)
*ToolApi* | [**tool_vbo_status**](docs/ToolApi.md#tool_vbo_status) | **GET** /tool/vbo_status/ | Check Value-Based Optimization eligibility [Tool Vbo_status](https://ads.tiktok.com/marketing_api/docs?id&#x3D;1770016073586753)
*CatalogApi* | [**catalog_available_country_get**](docs/CatalogApi.md#catalog_available_country_get) | **GET** /catalog/available_country/get/ | Get the countries and regions that ads for a catalog can be delivered to. [Catalog Available Country Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1740491257516034)
*CatalogApi* | [**catalog_capitalize**](docs/CatalogApi.md#catalog_capitalize) | **POST** /catalog/capitalize/ | Migrate catalogs under your ad account to your Business Center. [Catalog Capitalize](https://business-api.tiktok.com/portal/docs?id&#x3D;1740490222539778)
*CatalogApi* | [**catalog_create**](docs/CatalogApi.md#catalog_create) | **POST** /catalog/create/ | Create a catalog by specifying information such as name, targeted locations, and currency. [Catalog Create](https://business-api.tiktok.com/portal/docs?id&#x3D;1740306481704961)
*CatalogApi* | [**catalog_delete**](docs/CatalogApi.md#catalog_delete) | **POST** /catalog/delete/ | Delete a catalog. [Catalog Delete](https://business-api.tiktok.com/portal/docs?id&#x3D;1740310064588801)
*CatalogApi* | [**catalog_eventsource_bind**](docs/CatalogApi.md#catalog_eventsource_bind) | **POST** /catalog/eventsource/bind/ | Bind app or website event sources to a catalog in a Business Center. [Catalog Eventsource Bind](https://business-api.tiktok.com/portal/docs?id&#x3D;1740492491200513)
*CatalogApi* | [**catalog_eventsource_bind_get**](docs/CatalogApi.md#catalog_eventsource_bind_get) | **GET** /catalog/eventsource_bind/get/ | Get event source binding information. [Catalog Eventsource Bind Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1740492531343362)
*CatalogApi* | [**catalog_eventsource_unbind**](docs/CatalogApi.md#catalog_eventsource_unbind) | **POST** /catalog/eventsource/unbind/ | Unbind event sources from a catalog. [Catalog Eventsource Unbind](https://business-api.tiktok.com/portal/docs?id&#x3D;1740492512449538)
*CatalogApi* | [**catalog_feed_delete**](docs/CatalogApi.md#catalog_feed_delete) | **POST** /catalog/feed/delete/ | Delete a feed. [Catalog Feed Delete](https://business-api.tiktok.com/portal/docs?id&#x3D;1740665210863617)
*CatalogApi* | [**catalog_feed_get**](docs/CatalogApi.md#catalog_feed_get) | **GET** /catalog/feed/get/ | Get all feeds or a particular feed. [Catalog Feed Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1740665183073281)
*CatalogApi* | [**catalog_get**](docs/CatalogApi.md#catalog_get) | **GET** /catalog/get/ | Get all catalogs or a particular catalog. [Catalog Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1740315452868610)
*CatalogApi* | [**catalog_lexicon_get**](docs/CatalogApi.md#catalog_lexicon_get) | **GET** /catalog/lexicon/get/ | Get the lexicon for your catalog for use in ad texts. [Catalog Lexicon Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1740488375815169)
*CatalogApi* | [**catalog_location_currency_get**](docs/CatalogApi.md#catalog_location_currency_get) | **GET** /catalog/location_currency/get/ | Get supported locations and corresponding currencies for Catalog API. [Catalog Location Currency Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1740491571747841)
*CatalogApi* | [**catalog_overview**](docs/CatalogApi.md#catalog_overview) | **GET** /catalog/overview/ | Get the number of products in different audit statuses in a catalog. [Catalog Overview](https://business-api.tiktok.com/portal/docs?id&#x3D;1740492470201345)
*CatalogApi* | [**catalog_product_delete**](docs/CatalogApi.md#catalog_product_delete) | **POST** /catalog/product/delete/ | Delete products in bulk. [Catalog Product Delete](https://business-api.tiktok.com/portal/docs?id&#x3D;1740562489236481)
*CatalogApi* | [**catalog_product_file**](docs/CatalogApi.md#catalog_product_file) | **POST** /catalog/product/file/ | Upload products via file URL. [Catalog Product File](https://business-api.tiktok.com/portal/docs?id&#x3D;1740496787164161)
*CatalogApi* | [**catalog_set_product_get**](docs/CatalogApi.md#catalog_set_product_get) | **GET** /catalog/set/product/get/ | Get products in a product set. [Catalog Set Product Get](https://business-api.tiktok.com/portal/docs?id&#x3D;1740571478441986)
*CatalogApi* | [**catalog_update**](docs/CatalogApi.md#catalog_update) | **POST** /catalog/update/ | Use this endpoint to update the name of a catalog. The catalog must be under a Business Center. [Catalog Update](https://business-api.tiktok.com/portal/docs?id&#x3D;1740306544966657)

## Documentation For Models

 - [AdAcoBody](docs/AdAcoBody.md)
 - [AdAcoBodyAvatarIcon](docs/AdAcoBodyAvatarIcon.md)
 - [AdAcoBodyAvatarIconList](docs/AdAcoBodyAvatarIconList.md)
 - [AdAcoBodyCallToActionList](docs/AdAcoBodyCallToActionList.md)
 - [AdAcoBodyCardList](docs/AdAcoBodyCardList.md)
 - [AdAcoBodyCommonMaterial](docs/AdAcoBodyCommonMaterial.md)
 - [AdAcoBodyCommonMaterialTrackingInfo](docs/AdAcoBodyCommonMaterialTrackingInfo.md)
 - [AdAcoBodyDeeplinkList](docs/AdAcoBodyDeeplinkList.md)
 - [AdAcoBodyDisplayNameList](docs/AdAcoBodyDisplayNameList.md)
 - [AdAcoBodyLandingPageUrls](docs/AdAcoBodyLandingPageUrls.md)
 - [AdAcoBodyMediaInfo](docs/AdAcoBodyMediaInfo.md)
 - [AdAcoBodyMediaInfoImageInfo](docs/AdAcoBodyMediaInfoImageInfo.md)
 - [AdAcoBodyMediaInfoList](docs/AdAcoBodyMediaInfoList.md)
 - [AdAcoBodyMediaInfoVideoInfo](docs/AdAcoBodyMediaInfoVideoInfo.md)
 - [AdAcoBodyPageList](docs/AdAcoBodyPageList.md)
 - [AdAcoBodyTitleList](docs/AdAcoBodyTitleList.md)
 - [AdAcoUpdateBody](docs/AdAcoUpdateBody.md)
 - [AdCreateBody](docs/AdCreateBody.md)
 - [AdStatusUpdateBody](docs/AdStatusUpdateBody.md)
 - [AdUpdateBody](docs/AdUpdateBody.md)
 - [AdUploadBody](docs/AdUploadBody.md)
 - [AdcreateCreatives](docs/AdcreateCreatives.md)
 - [AdcreateDisclaimerClickableTexts](docs/AdcreateDisclaimerClickableTexts.md)
 - [AdcreateDisclaimerText](docs/AdcreateDisclaimerText.md)
 - [AdgroupCreateBody](docs/AdgroupCreateBody.md)
 - [AdgroupStatusUpdateBody](docs/AdgroupStatusUpdateBody.md)
 - [AdgroupUpdateBody](docs/AdgroupUpdateBody.md)
 - [AdgroupcreateActions](docs/AdgroupcreateActions.md)
 - [AdgroupcreateAudienceRule](docs/AdgroupcreateAudienceRule.md)
 - [AdgroupcreateAudienceRuleExclusions](docs/AdgroupcreateAudienceRuleExclusions.md)
 - [AdgroupcreateAudienceRuleExclusionsEventSources](docs/AdgroupcreateAudienceRuleExclusionsEventSources.md)
 - [AdgroupcreateAudienceRuleExclusionsFilter](docs/AdgroupcreateAudienceRuleExclusionsFilter.md)
 - [AdgroupcreateAudienceRuleExclusionsFilterFilters](docs/AdgroupcreateAudienceRuleExclusionsFilterFilters.md)
 - [AdgroupcreateAudienceRuleExclusionsRules](docs/AdgroupcreateAudienceRuleExclusionsRules.md)
 - [AdgroupcreateAudienceRuleInclusions](docs/AdgroupcreateAudienceRuleInclusions.md)
 - [AdgroupcreateExcludedCustomActions](docs/AdgroupcreateExcludedCustomActions.md)
 - [AdgroupcreateIncludedCustomActions](docs/AdgroupcreateIncludedCustomActions.md)
 - [AdgroupcreateTargetingExpansion](docs/AdgroupcreateTargetingExpansion.md)
 - [AdminDeleteBody](docs/AdminDeleteBody.md)
 - [AdupdateCreatives](docs/AdupdateCreatives.md)
 - [AdvertiserCreateBody](docs/AdvertiserCreateBody.md)
 - [AdvertiserUpdateBody](docs/AdvertiserUpdateBody.md)
 - [AdvertiserupdateAdvertiserBudgets](docs/AdvertiserupdateAdvertiserBudgets.md)
 - [AdvertiserupdateQualificationImages](docs/AdvertiserupdateQualificationImages.md)
 - [AppCreateBody](docs/AppCreateBody.md)
 - [AppUpdateBody](docs/AppUpdateBody.md)
 - [AppcreateTrackingUrl](docs/AppcreateTrackingUrl.md)
 - [AppupdateTrackingUrl](docs/AppupdateTrackingUrl.md)
 - [AssetAssignBody](docs/AssetAssignBody.md)
 - [AssetDeleteBody](docs/AssetDeleteBody.md)
 - [AssetGroupCreateBody](docs/AssetGroupCreateBody.md)
 - [AssetGroupDeleteBody](docs/AssetGroupDeleteBody.md)
 - [AssetGroupUpdateBody](docs/AssetGroupUpdateBody.md)
 - [AssetUnassignBody](docs/AssetUnassignBody.md)
 - [BcTransferBody](docs/BcTransferBody.md)
 - [BcadvertisercreateAdvertiserInfo](docs/BcadvertisercreateAdvertiserInfo.md)
 - [BcadvertisercreateBillingGroupInfo](docs/BcadvertisercreateBillingGroupInfo.md)
 - [BcadvertisercreateBillingInfo](docs/BcadvertisercreateBillingInfo.md)
 - [BcadvertisercreateContactInfo](docs/BcadvertisercreateContactInfo.md)
 - [BcadvertisercreateCustomerInfo](docs/BcadvertisercreateCustomerInfo.md)
 - [BcadvertisercreateQualificationInfo](docs/BcadvertisercreateQualificationInfo.md)
 - [BcassetGroupcreateAssets](docs/BcassetGroupcreateAssets.md)
 - [BcassetGroupcreateMembers](docs/BcassetGroupcreateMembers.md)
 - [BcmemberinviteExtUserRole](docs/BcmemberinviteExtUserRole.md)
 - [BidRecommendBody](docs/BidRecommendBody.md)
 - [BillingGroupCreateBody](docs/BillingGroupCreateBody.md)
 - [BillingGroupUpdateBody](docs/BillingGroupUpdateBody.md)
 - [CampaignCreateBody](docs/CampaignCreateBody.md)
 - [CampaignStatusUpdateBody](docs/CampaignStatusUpdateBody.md)
 - [CampaignUpdateBody](docs/CampaignUpdateBody.md)
 - [CatalogCapitalizeBody](docs/CatalogCapitalizeBody.md)
 - [CatalogCreateBody](docs/CatalogCreateBody.md)
 - [CatalogDeleteBody](docs/CatalogDeleteBody.md)
 - [CatalogUpdateBody](docs/CatalogUpdateBody.md)
 - [CatalogcreateCatalogConf](docs/CatalogcreateCatalogConf.md)
 - [CreativeportfoliocreateAdvancedAudioInfo](docs/CreativeportfoliocreateAdvancedAudioInfo.md)
 - [CreativeportfoliocreateAdvancedGestureIcon](docs/CreativeportfoliocreateAdvancedGestureIcon.md)
 - [CreativeportfoliocreateBadgeImageInfo](docs/CreativeportfoliocreateBadgeImageInfo.md)
 - [CreativeportfoliocreateBadgePosition](docs/CreativeportfoliocreateBadgePosition.md)
 - [CreativeportfoliocreatePortfolioContent](docs/CreativeportfoliocreatePortfolioContent.md)
 - [CreativeportfoliocreateStickerParam](docs/CreativeportfoliocreateStickerParam.md)
 - [CustomAudienceApplyBody](docs/CustomAudienceApplyBody.md)
 - [CustomAudienceCreateBody](docs/CustomAudienceCreateBody.md)
 - [CustomAudienceDeleteBody](docs/CustomAudienceDeleteBody.md)
 - [CustomAudienceShareBody](docs/CustomAudienceShareBody.md)
 - [CustomAudienceUpdateBody](docs/CustomAudienceUpdateBody.md)
 - [DmpcustomAudienceapplyContextInfo](docs/DmpcustomAudienceapplyContextInfo.md)
 - [DmpcustomAudiencefileuploadContextInfo](docs/DmpcustomAudiencefileuploadContextInfo.md)
 - [DmpcustomAudiencelookalikecreateContextInfo](docs/DmpcustomAudiencelookalikecreateContextInfo.md)
 - [DmpcustomAudiencelookalikecreateLookalikeSpec](docs/DmpcustomAudiencelookalikecreateLookalikeSpec.md)
 - [DmpcustomAudiencerulecreateRuleSpec](docs/DmpcustomAudiencerulecreateRuleSpec.md)
 - [DmpcustomAudiencerulecreateRuleSpecExclusionRuleSet](docs/DmpcustomAudiencerulecreateRuleSpecExclusionRuleSet.md)
 - [DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetFilterSet](docs/DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetFilterSet.md)
 - [DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetFilterSetFilters](docs/DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetFilterSetFilters.md)
 - [DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetFilterSetParameterFilters](docs/DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetFilterSetParameterFilters.md)
 - [DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetRules](docs/DmpcustomAudiencerulecreateRuleSpecExclusionRuleSetRules.md)
 - [DmpcustomAudiencerulecreateRuleSpecInclusionRuleSet](docs/DmpcustomAudiencerulecreateRuleSpecInclusionRuleSet.md)
 - [DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetFilterSet](docs/DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetFilterSet.md)
 - [DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetFilterSetFilters](docs/DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetFilterSetFilters.md)
 - [DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetFilterSetParameterFilters](docs/DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetFilterSetParameterFilters.md)
 - [DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetRules](docs/DmpcustomAudiencerulecreateRuleSpecInclusionRuleSetRules.md)
 - [DmpsavedAudiencecreateActions](docs/DmpsavedAudiencecreateActions.md)
 - [EventsourceBindBody](docs/EventsourceBindBody.md)
 - [EventsourceUnbindBody](docs/EventsourceUnbindBody.md)
 - [FeedDeleteBody](docs/FeedDeleteBody.md)
 - [FileImageAdUpload](docs/FileImageAdUpload.md)
 - [FileUploadBody](docs/FileUploadBody.md)
 - [FilteringAdGet](docs/FilteringAdGet.md)
 - [FilteringAdgroupGet](docs/FilteringAdgroupGet.md)
 - [FilteringAdvertiserBalanceGet](docs/FilteringAdvertiserBalanceGet.md)
 - [FilteringAdvertiserTransactionGet](docs/FilteringAdvertiserTransactionGet.md)
 - [FilteringBcAccountTransactionGet](docs/FilteringBcAccountTransactionGet.md)
 - [FilteringBcAssetAdminGet](docs/FilteringBcAssetAdminGet.md)
 - [FilteringBcAssetGet](docs/FilteringBcAssetGet.md)
 - [FilteringBcAssetGroupGet](docs/FilteringBcAssetGroupGet.md)
 - [FilteringBcAssetGroupList](docs/FilteringBcAssetGroupList.md)
 - [FilteringBcAssetMemberGet](docs/FilteringBcAssetMemberGet.md)
 - [FilteringBcBillingGroupGet](docs/FilteringBcBillingGroupGet.md)
 - [FilteringBcGet](docs/FilteringBcGet.md)
 - [FilteringBcMemberGet](docs/FilteringBcMemberGet.md)
 - [FilteringBcPartnerAssetGet](docs/FilteringBcPartnerAssetGet.md)
 - [FilteringBcPartnerGet](docs/FilteringBcPartnerGet.md)
 - [FilteringBcTransactionGet](docs/FilteringBcTransactionGet.md)
 - [FilteringCampaignGet](docs/FilteringCampaignGet.md)
 - [FilteringReportIntegratedGet](docs/FilteringReportIntegratedGet.md)
 - [FilteringVideoAdSearch](docs/FilteringVideoAdSearch.md)
 - [IdentityCreateBody](docs/IdentityCreateBody.md)
 - [ImageUploadBody](docs/ImageUploadBody.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [LinkUpdateBody](docs/LinkUpdateBody.md)
 - [LookalikeCreateBody](docs/LookalikeCreateBody.md)
 - [LookalikeUpdateBody](docs/LookalikeUpdateBody.md)
 - [MaterialStatusUpdateBody](docs/MaterialStatusUpdateBody.md)
 - [MemberDeleteBody](docs/MemberDeleteBody.md)
 - [MemberInviteBody](docs/MemberInviteBody.md)
 - [MemberUpdateBody](docs/MemberUpdateBody.md)
 - [Oauth2AccessTokenBody](docs/Oauth2AccessTokenBody.md)
 - [PangleBlockListUpdateBody](docs/PangleBlockListUpdateBody.md)
 - [PartnerAddBody](docs/PartnerAddBody.md)
 - [PartnerDeleteBody](docs/PartnerDeleteBody.md)
 - [PixelBatchBody](docs/PixelBatchBody.md)
 - [PixelContent](docs/PixelContent.md)
 - [PixelContext](docs/PixelContext.md)
 - [PixelContextAd](docs/PixelContextAd.md)
 - [PixelContextPage](docs/PixelContextPage.md)
 - [PixelContextUser](docs/PixelContextUser.md)
 - [PixelProperties](docs/PixelProperties.md)
 - [PixelTrackBody](docs/PixelTrackBody.md)
 - [PixelTransferBody](docs/PixelTransferBody.md)
 - [PixelbatchBatch](docs/PixelbatchBatch.md)
 - [PortfolioCreateBody](docs/PortfolioCreateBody.md)
 - [ProductDeleteBody](docs/ProductDeleteBody.md)
 - [ProductFileBody](docs/ProductFileBody.md)
 - [ReporttaskcreateFiltering](docs/ReporttaskcreateFiltering.md)
 - [RuleCreateBody](docs/RuleCreateBody.md)
 - [SavedAudienceCreateBody](docs/SavedAudienceCreateBody.md)
 - [SavedAudienceDeleteBody](docs/SavedAudienceDeleteBody.md)
 - [ShareCancelBody](docs/ShareCancelBody.md)
 - [TargetingCategoryRecommendBody](docs/TargetingCategoryRecommendBody.md)
 - [TargetingInfoBody](docs/TargetingInfoBody.md)
 - [TargetingSearchBody](docs/TargetingSearchBody.md)
 - [TaskCancelBody](docs/TaskCancelBody.md)
 - [TaskCreateBody](docs/TaskCreateBody.md)
 - [TermConfirmBody](docs/TermConfirmBody.md)

## Documentation For Authorization

 All endpoints do not require authorization.

